==> balance-api-1.2-20200728.044947-3-sources.jar: cc/lechun/balance/dto/StorageCardDTO.java <==
package cc.lechun.balance.dto;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @Description:
 * @Author hans
 * @Date 2019/8/12 14:16
 * @Version 1.0
 */
public class StorageCardDTO implements Serializable {

    private static final long serialVersionUID = -1575085936850299951L;

    /*主键*/
    private String id;

    /*礼品标题*/
    private String giftTitle;

    /*礼品展示图片*/
    private String giftImg;

    /*购买金额*/
    private BigDecimal giftCash;

    /*赠送金额*/
    private BigDecimal freeCash;

    /*状态 0:删除;1:正常;2:停用*/
    private Integer giftState;

    /*商品ID*/
    private String proId;

    /*产品名称*/
    private String proName;

    /*平台分组标示*/
    private Integer platformGroupId;

    /*创建时间*/
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /*创建者*/
    private String createBy;

    /*更新时间*/
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /*更新者*/
    private String updateBy;

    /*备注*/
    private String remark;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getGiftTitle() {
        return giftTitle;
    }

    public void setGiftTitle(String giftTitle) {
        this.giftTitle = giftTitle;
    }

    public String getGiftImg() {
        return giftImg;
    }

    public void setGiftImg(String giftImg) {
        this.giftImg = giftImg;
    }

    public BigDecimal getGiftCash() {
        return giftCash;
    }

    public void setGiftCash(BigDecimal giftCash) {
        this.giftCash = giftCash;
    }

    public BigDecimal getFreeCash() {
        return freeCash;
    }

    public void setFreeCash(BigDecimal freeCash) {
        this.freeCash = freeCash;
    }

    public Integer getGiftState() {
        return giftState;
    }

    public void setGiftState(Integer giftState) {
        this.giftState = giftState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public String getProName() {
        return proName;
    }

    public void setProName(String proName) {
        this.proName = proName;
    }

    public Integer getPlatformGroupId() {
        return platformGroupId;
    }

    public void setPlatformGroupId(Integer platformGroupId) {
        this.platformGroupId = platformGroupId;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateBy() {
        return createBy;
    }

    public void setCreateBy(String createBy) {
        this.createBy = createBy;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getUpdateBy() {
        return updateBy;
    }

    public void setUpdateBy(String updateBy) {
        this.updateBy = updateBy;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> balance-api-1.3.6-20250115.055928-1-sources.jar: cc/lechun/balance/dto/StorageCardDTO.java <==
package cc.lechun.balance.dto;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @Description:
 * @Author hans
 * @Date 2019/8/12 14:16
 * @Version 1.0
 */
public class StorageCardDTO implements Serializable {

    private static final long serialVersionUID = -1575085936850299951L;

    /*主键*/
    private String id;

    /*礼品标题*/
    private String giftTitle;

    /*礼品展示图片*/
    private String giftImg;

    /*购买金额*/
    private BigDecimal giftCash;

    /*赠送金额*/
    private BigDecimal freeCash;

    /*总金额*/
    private BigDecimal totalCash;

    /*状态 0:删除;1:正常;2:停用*/
    private Integer giftState;

    /*商品ID*/
    private String proId;

    /*产品名称*/
    private String proName;

    /*平台分组标示*/
    private Integer platformGroupId;

    /*创建时间*/
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /*创建者*/
    private String createBy;

    /*更新时间*/
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /*更新者*/
    private String updateBy;

    /*备注*/
    private String remark;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getGiftTitle() {
        return giftTitle;
    }

    public void setGiftTitle(String giftTitle) {
        this.giftTitle = giftTitle;
    }

    public String getGiftImg() {
        return giftImg;
    }

    public void setGiftImg(String giftImg) {
        this.giftImg = giftImg;
    }

    public BigDecimal getGiftCash() {
        return giftCash;
    }

    public void setGiftCash(BigDecimal giftCash) {
        this.giftCash = giftCash;
    }

    public BigDecimal getFreeCash() {
        return freeCash;
    }

    public void setFreeCash(BigDecimal freeCash) {
        this.freeCash = freeCash;
    }

    public BigDecimal getTotalCash() {
        return totalCash;
    }

    public void setTotalCash(BigDecimal totalCash) {
        this.totalCash = totalCash;
    }

    public Integer getGiftState() {
        return giftState;
    }

    public void setGiftState(Integer giftState) {
        this.giftState = giftState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public String getProName() {
        return proName;
    }

    public void setProName(String proName) {
        this.proName = proName;
    }

    public Integer getPlatformGroupId() {
        return platformGroupId;
    }

    public void setPlatformGroupId(Integer platformGroupId) {
        this.platformGroupId = platformGroupId;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateBy() {
        return createBy;
    }

    public void setCreateBy(String createBy) {
        this.createBy = createBy;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getUpdateBy() {
        return updateBy;
    }

    public void setUpdateBy(String updateBy) {
        this.updateBy = updateBy;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}
